#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Empty placeholder indicator for creating plots in NinjaScript Strategies
    /// </summary>
    [Description("Empty placeholder indicator for creating plots in NinjaScript Strategies")]
    public class StrategyPlot : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int id = 1; // Default setting for Id
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.Orange, PlotStyle.Line, "Strategy Plot"));
            CalculateOnBarClose	= true;
            Overlay				= false;
            PriceTypeSupported	= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			// This is an empty indicator that just acts as a placeholder for creating a plot.
		}

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plot
        {
            get { return Values[0]; }
        }

        [Description("")]
        [Category("Parameters")]
        public int Id
        {
            get { return id; }
            set { id = Math.Max(0, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private StrategyPlot[] cacheStrategyPlot = null;

        private static StrategyPlot checkStrategyPlot = new StrategyPlot();

        /// <summary>
        /// Empty placeholder indicator for creating plots in NinjaScript Strategies
        /// </summary>
        /// <returns></returns>
        public StrategyPlot StrategyPlot(int id)
        {
            return StrategyPlot(Input, id);
        }

        /// <summary>
        /// Empty placeholder indicator for creating plots in NinjaScript Strategies
        /// </summary>
        /// <returns></returns>
        public StrategyPlot StrategyPlot(Data.IDataSeries input, int id)
        {
            checkStrategyPlot.Id = id;
            id = checkStrategyPlot.Id;

            if (cacheStrategyPlot != null)
                for (int idx = 0; idx < cacheStrategyPlot.Length; idx++)
                    if (cacheStrategyPlot[idx].Id == id && cacheStrategyPlot[idx].EqualsInput(input))
                        return cacheStrategyPlot[idx];

            StrategyPlot indicator = new StrategyPlot();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.Id = id;
            indicator.SetUp();

            StrategyPlot[] tmp = new StrategyPlot[cacheStrategyPlot == null ? 1 : cacheStrategyPlot.Length + 1];
            if (cacheStrategyPlot != null)
                cacheStrategyPlot.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheStrategyPlot = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Empty placeholder indicator for creating plots in NinjaScript Strategies
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.StrategyPlot StrategyPlot(int id)
        {
            return _indicator.StrategyPlot(Input, id);
        }

        /// <summary>
        /// Empty placeholder indicator for creating plots in NinjaScript Strategies
        /// </summary>
        /// <returns></returns>
        public Indicator.StrategyPlot StrategyPlot(Data.IDataSeries input, int id)
        {
            return _indicator.StrategyPlot(input, id);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Empty placeholder indicator for creating plots in NinjaScript Strategies
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.StrategyPlot StrategyPlot(int id)
        {
            return _indicator.StrategyPlot(Input, id);
        }

        /// <summary>
        /// Empty placeholder indicator for creating plots in NinjaScript Strategies
        /// </summary>
        /// <returns></returns>
        public Indicator.StrategyPlot StrategyPlot(Data.IDataSeries input, int id)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.StrategyPlot(input, id);
        }

    }
}
#endregion
