#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Strategy;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// Reference sample demonstrating how to plot from within a strategy
    /// </summary>
    [Description("Reference sample demonstrating how to plot from within a strategy")]
    public class SampleStrategyPlot : Strategy
    {
        #region Variables
        #endregion

        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose = true;
			
			// Create a multi-time frame strategy
			Add(PeriodType.Minute, 3);
			
			/* Add our blank placeholder indicators. The parameter we pass in is used to distinguish the two
			indicators from each other. */
			Add(StrategyPlot(0));
			Add(StrategyPlot(1));
			
			// Set the color for the indicator plots
			StrategyPlot(0).Plots[0].Pen.Color = Color.Blue;
			StrategyPlot(1).Plots[0].Pen.Color = Color.YellowGreen;
			
			// Set the panel which the plots will be placed on. 1 = price panel, 2 = panel under the price panel, etc.
			StrategyPlot(0).PanelUI = 1;
			StrategyPlot(1).PanelUI = 1;
			
			// For more options please see the forum tip titled "Adding Indicators to Strategies"
			// http://www.ninjatrader-support.com/vb/showthread.php?t=3228
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			/* Set the values of our indicators. One of them is set to the High of the primary bar series while the
			other is set to the High of the secondary bar series. This effectively creates a multi-time frame plot. */
			StrategyPlot(0).Value.Set(High[0]);
			StrategyPlot(1).Value.Set(Highs[1][0]);
        }

        #region Properties
        #endregion
    }
}
